"""
Purpose: CLI command modules namespace
LLM-Note:
  Dependencies: none | imported by [cli/main.py] | no direct tests
  Data flow: no exports (commands imported directly from submodules)
  State/Effects: no state
  Integration: namespace package for auth_commands, browser_commands, create, deploy_commands, doctor_commands, eval_commands, init, status_commands, etc.
  Performance: trivial
  Errors: none
Command modules for ConnectOnion CLI.
"""