"""
Purpose: CLI module entry point with version metadata
LLM-Note:
  Dependencies: none | imported by [cli/main.py, setup.py] | no direct tests
  Data flow: pure metadata (version string)
  State/Effects: no state
  Integration: exposes __version__ for CLI about/version commands
  Performance: trivial
  Errors: none
ConnectOnion CLI module.
"""

__version__ = "0.0.1b5"